#!/opt/conda/conda-bld/gdal_1643825005570/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehol/bin/python
# EASY-INSTALL-SCRIPT: 'GDAL==3.4.1','gdal_calc.py'
__requires__ = 'GDAL==3.4.1'
__import__('pkg_resources').run_script('GDAL==3.4.1', 'gdal_calc.py')
